@@ -66,7 +66,7 @@ class PhysicalChannelCollection(Sequence):
         else:
             raise DaqError(
                 'Invalid index type "{0}" used to access collection.'
-                .format(type(index)), DAQmxErrors.UNKNOWN.value)
+                .format(type(index)), DAQmxErrors.UNKNOWN)
 
     def __iter__(self):
         for channel_name in self.channel_names:
